"""Hyperlinks for pydantic models"""

__version__ = "0.2"

from .href import Href, Referrable
from .model import BaseReferrableModel, PrimaryKey
